@@ -46,10 +46,14 @@ class CodeTest(DuplicityTestCase):
     def run_checker(self, cmd, returncodes=[0]):
         process = subprocess.Popen(cmd,
                                    stdout=subprocess.PIPE,
-                                   stderr=subprocess.PIPE)
+                                   stderr=subprocess.PIPE,
+                                   universal_newlines=True)
         output = process.communicate()[0]
+        if len(output):
+            for line in output.split(u'\n'):
+                print(line, file=sys.stderr)
+            output = u""
         self.assertTrue(process.returncode in returncodes, output)
-        self.assertEqual(b"", output, output)
 
     @skipCodeTest
     def test_2to3(self):
@@ -78,6 +82,7 @@ class CodeTest(DuplicityTestCase):
         u"""Pylint test (requires pylint to be installed to pass)"""
         self.run_checker([
             u"pylint",
+            u"--rcfile=" + os.path.join(_top_dir, u"pylintrc"),
             os.path.join(_top_dir, u'duplicity'),
             os.path.join(_top_dir, u'bin/duplicity'),
             os.path.join(_top_dir, u'bin/rdiffdir')])
